# Sign Language Tools

Python library containing various tools for sign language processing.

This project is in an early stage of development.
Do not hesitate to contribute !

# Why?

Why not? It is useful to us, therefore it may be useful to you?

# What's included?

* Video Player to visualize sign language videos with corresponding annotations and landmarks.
* Data augmentation tools like transforms that can be used with Pytorch or Tensorflow, etc.
* Preprocessing of pose data with interpolation, resampling, smoothing, etc.
* Plotting functions using Matplotlib.

# What's next?

* More data augmentation and plotting!
* More tools for annotations.
* Tools for image processing.
* To be discussed...